==> kolourpaint-16.04.3.tar.xz: kolourpaint-16.04.3/commands/tools/flow/kpToolFlowCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_FLOW_COMMAND_H
#define KP_TOOL_FLOW_COMMAND_H


#include <kpNamedCommand.h>


class QPoint;
class QRect;


class kpToolFlowCommand : public kpNamedCommand
{
public:
    kpToolFlowCommand (const QString &name, kpCommandEnvironment *environ);
    virtual ~kpToolFlowCommand ();

    virtual kpCommandSize::SizeType size () const;

    virtual void execute ();
    virtual void unexecute ();

    // interface for kpToolFlowBase
    void updateBoundingRect (const QPoint &point);
    void updateBoundingRect (const QRect &rect);
    void finalize ();
    void cancel ();

private:
    void swapOldAndNew ();

    struct kpToolFlowCommandPrivate * const d;
};


#endif  // KP_TOOL_FLOW_COMMAND_H

==> kolourpaint_24.12.3.orig.tar.xz: kolourpaint-24.12.3/commands/tools/flow/kpToolFlowCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_FLOW_COMMAND_H
#define KP_TOOL_FLOW_COMMAND_H


#include "commands/kpNamedCommand.h"


class QPoint;
class QRect;


class kpToolFlowCommand : public kpNamedCommand
{
public:
    kpToolFlowCommand (const QString &name, kpCommandEnvironment *environ);
    ~kpToolFlowCommand () override;

    kpCommandSize::SizeType size () const override;

    void execute () override;
    void unexecute () override;

    // interface for kpToolFlowBase
    void updateBoundingRect (const QPoint &point);
    void updateBoundingRect (const QRect &rect);
    void finalize ();
    void cancel ();

private:
    void swapOldAndNew ();

    struct kpToolFlowCommandPrivate * const d;
};


#endif  // KP_TOOL_FLOW_COMMAND_H
